@@ -276,13 +276,14 @@ class NVD3Chart:
         #Create SVG div with style
         if self.width:
             if self.width[-1] != '%':
-                self.width += 'px'
-            self.style += 'width:%s;' % self.width
+                self.style += 'width:%spx;' % self.width
+            else:
+                self.style += 'width:%s;' % self.width
         if self.height:
             if self.height[-1] != '%':
-                self.height += 'px'
-            self.style += 'height:%s;' % self.height
-
+                self.style += 'height:%spx;' % self.height
+            else:
+                self.style += 'height:%s;' % self.height
         if self.style:
             self.style = 'style="%s"' % self.style
 
